@@ -73,7 +73,10 @@ STRUCTURE = Nav(
 			lazy_gettext("Archétypes"),
 			index=True,
 			children=[
+				Nav(lazy_gettext("Isamaru, Hound of Konda")),
+				Nav(lazy_gettext("Kelsien, the Plague")),
 				Nav(lazy_gettext("Kess, Dissident Mage")),
+				Nav(lazy_gettext("Rowan and Will Kenrith")),
 				Nav(lazy_gettext("Winota, Joiner of Forces")),
 			],
 		),
@@ -102,6 +105,7 @@ STRUCTURE = Nav(
 						Nav(lazy_gettext("Les Grosses Créatures")),
 					],
 				),
+				Nav(lazy_gettext("Les Cantrips")),
 				Nav(lazy_gettext("Les Piocheurs")),
 				Nav(lazy_gettext("Les Spot Removals")),
 				Nav(lazy_gettext("Les Mass Removals")),
